summaryrefslogtreecommitdiffstats
path: root/src/import/hwpf/fapi2/include
diff options
context:
space:
mode:
Diffstat (limited to 'src/import/hwpf/fapi2/include')
-rw-r--r--src/import/hwpf/fapi2/include/error_info_defs.H6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/import/hwpf/fapi2/include/error_info_defs.H b/src/import/hwpf/fapi2/include/error_info_defs.H
index 2bec413f6..12198e499 100644
--- a/src/import/hwpf/fapi2/include/error_info_defs.H
+++ b/src/import/hwpf/fapi2/include/error_info_defs.H
@@ -54,10 +54,10 @@ struct sbeFfdc_t
uint64_t data;
} __attribute__((packed));
// 10 entries limits the size of SbeFfdcData_t to 128 bytes
enum
{
- MAX_SBE_FFDC_ENTRIES = 10
+ MAX_SBE_FFDC_ENTRIES = 20
};
// Data type for SBE ffdc buffer sent through fifo
@@ -66,7 +66,7 @@ typedef struct
uint32_t fapiRc; // Return code from failure
uint32_t ffdcLength; // length of Fapi FFDC data (in bytes)
struct sbeFfdc_t ffdcData[MAX_SBE_FFDC_ENTRIES]; // fapi FFDC data
-} SbeFfdcData_t; // 128 bytes
+} SbeFfdcData_t; // ~248 bytes
///
/// @brief Type to hold the ffdc element in the ffdc class
OpenPOWER on IntegriCloud
@@ -54,10 +54,10 @@ struct sbeFfdc_t
uint64_t data;
} __attribute__((packed));
-// 10 entries limits the size of SbeFfdcData_t to 128 bytes
+// 20 entries limits the size of SbeFfdcData_t under 256 bytes
enum
{